/*
 * Copyright (c) 2010	IAC Corp All rights reserved.
 *
 * IAC SDK - all SDK functions
 */
 
#ifndef	_IACUTIL_H_
#define _IACUTIL_H_

#include <windows.h>

#ifndef _PC_EMULATOR
extern "C"
{
#endif

enum DI_ERRORNO
{
	DI_ERRORNO_GENEERAL_ERROR_TO_SET,						/**< Error not set yet */

	DI_ERRORNO_INVALID_NO_ERROR,							/**< No Error */
	DI_ERRORNO_INVALID_TYPE,								/**< Invalid Type */
	DI_ERRORNO_INVALID_PARAM,								/**< Invalided Parameter(s) */

	DI_ERRORNO_HARDWARE_ERROR,								/**< Hardware Low Level Error */

	NFC_RESULT_SUCCESS					=0xFFDC, 			/**< Execution success. */
	NFC_RESULT_DRIVER_NOT_INITIALIZED	=0xFF01, 			/**< Driver is not initialized. */
	NFC_RESULT_INVALID_PARAMETER		=0xFF02, 			/**< Invalid parameters. */
	NFC_RESULT_NFC_BUSY					=0xFF03, 			/**< NFC is busy. */
	NFC_RESULT_OUT_OF_RESOURCE			=0xFF04, 			/**< System resources insufficient. */
	NFC_RESULT_LOW_LAYER_ERROR			=0xFF05, 			/**< Errors related to the lower layers. */
	NFC_RESULT_NOT_OPEN					=0xFF06, 			/**< Not opened. */
	NFC_RESULT_TYPE_NOT_SUPPORT			=0xFF07, 			/**< Type NOT support. */
};

/*! \addtogroup GP1 Platform / Device Information
  *  Additional documentation for group 'Platform / Device Information'
  *  @{
  */
/*! Used in function apiGetDeviceInformation() & apiSetDeviceInformation() */
enum DEVICE_INFO_TYPE
{
	DEVICE_INFO_TYPE_OS_VERSION,							/**< H22 OS Version */
	DEVICE_INFO_TYPE_BOOTLOADER_VERSION,					/**< Boot loader Version */
	DEVICE_INFO_TYPE_IMEI,									/**< IMEI */
	DEVICE_INFO_TYPE_CUSTOMER_SERIAL_NUMBER,				/**< Customer Serial Number */
	DEVICE_INFO_TYPE_WIFI_ADDRESS,							/**< WiFi MAC Address */
	DEVICE_INFO_TYPE_BLUETOOTH_ADDRESS,						/**< Bluetooth MAC Address */
	DEVICE_INFO_TYPE_COMPANY_SERIAL_NUMBER,					/**< Company Serial Number */
	DEVICE_INFO_TYPE_PCV_VERSION,							/**< PCV Production Version */
};

/*!
 *  \brief This function gets the information of different parts. \n Including H22 OS Version, Boot loader Version, IMEI, Customer Serial Number, WiFi MAC Address, Bluetooth MAC Address, Company Serial Number and PCV Production Version.
 *  \param [in] dwInfoType		A DWORD specifying which type of Information is being requested. \n Could be any member defined in enum DEVICE_INFO_TYPE.
 *  \param [out] lpszValue		A pointer to a sting buff, which will be used to retrieve requested information in the form of a null-terminated string. \n The length of the information string depends on dwInfoType parameter. If buff size is too small, it will not be set, the function should return FALSE and lpdwError be set accordingly.
 *  \param [in,out] lpdwLen		A pointer to a DWORD variable indicating the size of retrieving buff size in character. The length of buff being set will be also stored after return. If buff size is too small, this returned value tells the required buff size, , the function should return FALSE and lpdwError be set accordingly.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \remarks The minimum length of the buff (lpszValue) depends on dwInfoType parameter according, reference the table below:
		<TABLE>
		<TR><TH>DEVICE_INFO_TYPE</TH>							<TH>Minimum length of lpszValue</TH>	<TH>Example</TH>			</TR>
		<TR><TD>DEVICE_INFO_TYPE_OS_VERSION</TD>				<TD>12+1</TD>								<TD>0.17.03A</TD>			</TR>
		<TR><TD>DEVICE_INFO_TYPE_BOOTLOADER_VERSION</TD>		<TD>12+1</TD>								<TD>0.05.03</TD>			</TR>
		<TR><TD>DEVICE_INFO_TYPE_IMEI</TD>						<TD>15+1</TD>							<TD>123455432112345</TD>	</TR>
		<TR><TD>DEVICE_INFO_TYPE_CUSTOMER_SERIAL_NUMBER</TD>	<TD>12+1</TD>							<TD>NA</TD>					</TR>
		<TR><TD>DEVICE_INFO_TYPE_WIFI_ADDRESS</TD>				<TD>12+1</TD>							<TD>001122334455</TD>		</TR>
		<TR><TD>DEVICE_INFO_TYPE_BLUETOOTH_ADDRESS</TD>			<TD>12+1</TD>							<TD>112233445566</TD>		</TR>
		<TR><TD>DEVICE_INFO_TYPE_COMPANY_SERIAL_NUMBER</TD>		<TD>16+1</TD>							<TD>NA</TD>					</TR>
		<TR><TD>DEVICE_INFO_TYPE_PCV_VERSION</TD>				<TD>8+1</TD>							<TD>NA</TD>					</TR>
		</TABLE>
		* The +1 is reserved for null-terminator.
 *  \return TRUE - Success to get the device information
 *  \return FALSE - Fail to get the device information. To get more error information, see parameter lpdwError.
 */
BOOL apiGetDeviceInformation(DWORD dwInfoType, LPTSTR lpszValue, DWORD *lpdwLen, DWORD *lpdwError);

/*!
 *  \brief This function set the information of different parts. \n Including Customer Serial Number, Bluetooth MAC Address and Company Serial Number only.
 *  \param [in] dwInfoType		A DWORD specifying which type of Information is being requested. \n Could be DEVICE_INFO_TYPE_CUSTOMER_SERIAL_NUMBER, DEVICE_INFO_TYPE_BLUETOOTH_ADDRESS, DEVICE_INFO_TYPE_COMPANY_SERIAL_NUMBER (defined in enum DEVICE_INFO_TYPE).
 *  \param [in] lpszValue 		A pointer to a null-terminated string, which contains the information to set. \n The length of the information string depends on dwInfoType parameter. Reference apiGetDeviceInformation() for examples. If containing information is not accepted, such as inappropriate length, wrong format or containing illegal characters, the function will return FALSE. Additional error code will be set in lpdwError.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to set the device information
 *  \return FALSE - Fail to set the device information. To get more error information, see parameter lpdwError.
 */
BOOL apiSetDeviceInformation(DWORD dwInfoType, LPCTSTR lpszValue, DWORD *lpdwError);

/*! @} */


/*! \addtogroup GP2 Accelerometer
  *  The following definition and functions are for 'Accelerometer'
  *  @{
  */

/*! Used in function apiSetGSensorPower() & apiGetGSensorPower() */
enum GSENSOR_POWER
{
	GSENSOR_ON, 		/**< The gravity sensor is On */
	GSENSOR_OFF, 	/**< The gravity sensor is Off */
};
/*!
 *  \brief This function will set the gravity sensor's power status (ON/OFF).
 *  \param [in] dwValue		A DWORD specifying whether to turn on or off the gravity sensor (defined in GSENSOR_POWER).
 *  \param [out] lpdwError	A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to set gravity sensor's power status.
 *  \return FALSE - Fail to set gravity sensor's power status. To get more error information, see parameter lpdwError.
 */
BOOL apiSetGSensorPower(DWORD dwValue, DWORD *lpdwError);

/*!
 *  \brief This function will get gravity sensor's power status (ON/OFF).
 *  \param [out] lpdwValue		A pointer to a DWORD to retrieve the status of gravity sensor (defined in GSENSOR_POWER).
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get gravity sensor's power status.
 *  \return FALSE - Fail to get gravity sensor's power status. To get more error information, see parameter lpdwError.
 */
BOOL apiGetGSensorPower(DWORD *lpdwValue, DWORD *lpdwError);

/*! Used in function apiGetGSensorScreenRotation() */
enum GSENSOR_ROTATION
{
	GSENSOR_ROTATE_0, 			/**< 0 degree */
	GSENSOR_ROTATE_90, 			/**< 90 degrees in a clockwise direction */
	GSENSOR_ROTATE_180, 		/**< 180 degrees */
	GSENSOR_ROTATE_270, 		/**< 270 degrees in a clockwise direction */
};
/*!
 *  \brief This function will get gravity sensor rotate direction value.
 *  \param [out] lpdwValue		A pointer to a DWORD to retrieve rotate angle value (defined in enum GSENSOR_ROTATION).
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get gravity sensor rotate direction value.
 *  \return FALSE - Fail to get gravity sensor rotate direction value. To get more error information, see parameter lpdwError.
 */
BOOL apiGetGSensorScreenRotation(DWORD *lpdwValue, DWORD *lpdwError);

/*! Used in function apiGetGSensorAcceleration() */
typedef struct _GSENSOR_ACCELERATION
{
	DWORD dwAcclX;				/**< acceleration in the X dimension */
	DWORD dwAcclY;				/**< acceleration in the Y dimension */
	DWORD dwAcclZ;				/**< acceleration in the Z dimension */
}GSENSOR_ACCELERATION;
/*!
 *  \brief This function will get gravity sensor's acceleration value in 3-dimensions.
 *  \param [out] lpAcceleration		A pointer to a struct of GSENSOR_ACCELERATION to retrieve the acceleration.
 *  \param [out] lpdwError			A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get gravity sensor's acceleration.
 *  \return FALSE - Fail to get gravity sensor's acceleration. To get more error information, see parameter lpdwError.
 */
BOOL apiGetGSensorAcceleration(GSENSOR_ACCELERATION *lpAcceleration, DWORD *lpdwError);

/*!
 *  \brief This function creates a connection to the gravity sensor driver to enable real-time monitoring of the device spatial movement.
 *  \param [in] hNewGSensorReading	A HANDLE to a Windows Embedded CE event created using CreateEvent, or NULL. The gravity sensor driver signals the past event whenever there is a new gravity sensor reading.
 *  \param [out] lphGSensorDevice	A pointer to a HANDLE. If successful, returns a HANDLE to the gravity sensor driver. If unsuccessful, returns NULL. 
 *  \param [out] lpdwError 			A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to create a connection to the gravity sensor driver.
 *  \return FALSE - Fail to create a connection to the gravity sensor driver. To get more error information, see parameter lpdwError.
 */
BOOL apiGSensorOpenDevice(HANDLE hNewGSensorReading, HANDLE *lphGSensorDevice,DWORD *lpdwError);

/*!
 *  \brief This function closes a connection to the gravity sensor driver.
 *  \param [in] hGSensorDevice	A HANDLE returned by a call to apiGSensorOpenDevice. 
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to close a connection to the gravity sensor driver.
 *  \return FALSE - Fail to close a connection to the gravity sensor driver. To get more error information, see parameter lpdwError.
 */
BOOL apiGSensorCloseDevice(HANDLE hGSensorDevice, DWORD *lpdwError);

/*! @} */


/*! \addtogroup GP3 Ambient Light Sensor
  *  The following definition and functions are for 'Ambient Light Sensor'
  *  @{
  */
/*!
 *  \brief This function will get light sensor's current brightness level value.
 *  \param [out] lpdwValue		A pointer to a DWORD to retrieve the value of Bright Level, range from 0 to 5. If Light sensor is Off, this value will be 0. When Light sensor is On, the value will be a positive number. (The larger number means the brighter.)
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get light sensor's brightness level.
 *  \return FALSE - Fail to get light sensor's brightness level. To get more error information, see parameter lpdwError.
 */
BOOL apiGetLightSensorInfo(DWORD *lpdwValue, DWORD *lpdwError);

/*! Used in function apiSetLightSensorPower() */
enum LIGHT_SENSOR_POWER
{
	LIGHT_SENSOR_ON, 	/**< The Light sensor is On */
	LIGHT_SENSOR_OFF, 	/**< The Light sensor is Off */
};

/*!
 *  \brief This function will turn light sensor on or off.
 *  \param [in] dwValue		A DWORD specifying whether to turn on or off the light sensor (defined in enum LIGHT_SENSOR_POWER).
 *  \param [out] lpdwError	A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to the set light sensor's power.
 *  \return FALSE - Fail to the set light sensor's power. To get more error information, see parameter lpdwError.
 */
BOOL apiSetLightSensorPower(DWORD dwValue, DWORD *lpdwError);

/*!
 *  \brief This function creates a connection to the light sensor driver to enable real-time monitoring of brightness in the environment.
 *  \param [in] hNewLightSensorReading		A HANDLE to a Windows Embedded CE event created using CreateEvent, or NULL. The light sensor driver signals the past event whenever there is a new Light Sensor reading.
 *  \param [out] lphLightSensorDevice		A pointer to a HANDLE. If successful, returns a HANDLE to the light sensor driver. If unsuccessful, returns NULL.
 *  \param [out] lpdwError					A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to create a connection to the light sensor driver.
 *  \return FALSE - Fail to create a connection to the light sensor driver. To get more error information, see parameter lpdwError.
 */
BOOL apiLightSensorOpenDevice(HANDLE hNewLightSensorReading, HANDLE *lphLightSensorDevice, DWORD *lpdwError);

/*!
 *  \brief This function closes the connection to the light sensor driver.
 *  \param [in] hLightSensorDevice		A HANDLE returned by a call to apiLightSensorOpenDevice. 
 *  \param [out] lpdwError				A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to close the connection to the light sensor driver.
 *  \return FALSE - Fail to close the connection to the light sensor driver. To get more error information, see parameter lpdwError.
 */
BOOL apiLightSensorCloseDevice(HANDLE hLightSensorDevice, DWORD *lpdwError);
/*! @} */


/*! \addtogroup GP4 Barcode Sensor
  *  The following definition and functions are for 'Barcode Sensor'
  *  @{
  */

/*! @} */


/*! \addtogroup GP5 CCX Supplicant
  *  The following definition and functions are for 'CCX Supplicant'
  *  @{
  */

/*! @} */


/*! \addtogroup GP6 Near Field Communication (RFID)
  *  The following definition and functions are for 'RFID'
  *  @{
  */
/*! Used in function apiSetNfcPower() */
enum NFC_POWER
{
	NFC_POWER_OFF=0x00, 	/**< NFC power is Off */
	NFC_POWER_ON=0x01, 	/**< NFC power is On */
};

/*!
 *  \brief This function turns NFC power on or off.
 *  \param [in] dwPowerType A DWORD specifying whether to turn on or off the NFC power (defined in enum NFC_POWER).
 *  \param [out] lpdwError A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to power NFC on or off .
 *  \return FALSE - Fail to power NFC on or off. To get more error information, see parameter lpdwError.
 */
BOOL apiSetNfcPower(DWORD dwPowerType, DWORD *lpdwError);

/*! Used in function apiNfcPolling() */
enum NFC_POLLING_TYPE
{
	NFC_POLLING_TYPE_ISO14443A		=0x01,					/**< ISO14443A */
	NFC_POLLING_TYPE_ISO14443B		=0x02,					/**< ISO14443B */
	NFC_POLLING_TYPE_FELICA212		=0x04,					/**< FELICA21 */
	NFC_POLLING_TYPE_FELICA424		=0x08,					/**< FELICA424 */
	NFC_POLLING_TYPE_ISO15693		=0X10,					/**< ISO15693 */
};

/*! Used in function apiNfcPolling() & apiNfcTransceive() */
enum NFC_DATA_FORMAT_TYPE
{
	NFC_DATA_FORMAT_TYPE_A			=6,					/**< TYPE A */
	NFC_DATA_FORMAT_TYPE_B			=7,					/**< TYPE B */
	NFC_DATA_FORMAT_FELICA			=8,					/**< FELICA */
	NFC_DATA_FORMAT_JEWEL			=9,					/**< JEWEL */
	NFC_DATA_FORMAT_MIFARE_1K		=10,				/**< MIFARE 1K */
	NFC_DATA_FORMAT_MIFARE_UL		=11,				/**< MIFARE UL */
	NFC_DATA_FORMAT_MIFARE_DESFIRE	=12,				/**< MIFARE DESFIRE */
	NFC_DATA_FORMAT_ISO15693		=14,				/**< ISO15693 */
	NFC_DATA_FORMAT_MIFARE_MINI 	= 15	,			/**< MIFARE MINI */
};

/*!
 *  \brief This function performs a polling to detect the selected type of card. \n It is called to discover the remote devices.
 *  \param [in,out] lpdwPollingType		A DWORD specifying the type of access to the object on using as an input (defined in NFC_POLLING_TYPE). As return value, it will be set in order to retrieve the returning data type (defined in NFC_DATA_FORMAT_TYPE).
 *  \param [out] lpdwResponseSize		A pointer to a DWORD, which indicates the size of lpResponseData and also is used to retrieve the number of bytes in response data.
 *  \param [out] lpResponseData			A pointer to a buffer that receives the data from remote object.
 *  \param [out] lpdwError 				A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \remarks Reference the tables below for the formats of returned data:
		<TABLE>
		<TR><TD>  <b>TypeA</b>  </TD></TR>
		<TR><TD>1 byte					</TD><TD>Tagtype=6		</TD></TR>
		<TR><TD>1 byte					</TD><TD>UidLength			</TD></TR>
		<TR><TD>10 bytes[MAX]			</TD><TD>Uid						</TD></TR>
		<TR><TD>1 byte					</TD><TD>AppDateLength	</TD></TR>
		<TR><TD>48 bytes[MAX]			</TD><TD>AppDate(Application data information of the tag discovered)	</TD></TR>
		<TR><TD>1 byte					</TD><TD>Sak						</TD></TR>
		<TR><TD>2 bytes					</TD><TD>AtqA						</TD></TR>
		</TABLE>
		<br>
		<TABLE>
		<TR><TD>  <b>TypeB</b>  </TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Tagtype=7		</TD></TR>
		<TR><TD>12 bytes				</TD>	<TD>AtqRes				</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Afi (Application Family Identifier)</TD></TR>
		</TABLE>
		<br>
		<TABLE>
		<TR><TD>  <b>Mifare</b>  </TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Tagtype: \n MIFARE1K=10 \n MIFAREUL=11 \n MIFAREDESFIRE=12</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>UidLength			</TD></TR>
		<TR><TD>10 bytes[MAX]			</TD>	<TD>Uid						</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Sak						</TD></TR>
		<TR><TD>2 bytes					</TD>	<TD>AtqA					</TD></TR>
		</TABLE>
		<br>
		<TABLE>
		<TR><TD>  <b>Felica</b>  </TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Tagtype=8		</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>IDmLength			</TD></TR>
		<TR><TD>10 bytes[MAX]			</TD>	<TD>IDm						</TD></TR>
		<TR><TD>8 bytes					</TD>	<TD>PMm						</TD></TR>
		<TR><TD>2 bytes					</TD>	<TD>SystemCode		</TD></TR>
		</TABLE>
		<br>
		<TABLE>
		<TR><TD>  <b>ISO15693</b>  </TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Tagtype=14	</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>UidLength			</TD></TR>
		<TR><TD>8 bytes[MAX]			</TD>	<TD>Uid						</TD></TR>
		<TR><TD>1 byte					</TD>	<TD>Afi (Application Family Identifier)</TD></TR>
		</TABLE>
 *  \return TRUE - Success to poll the NFC card.
 *  \return FALSE - Fail to poll the NFC card. To get more error information, see parameter lpdwError.
 */
BOOL apiNfcPolling(DWORD *lpdwPollingType, DWORD *lpdwResponseSize, void *lpResponseData, DWORD *lpdwError);

/*!
 *  \brief This function allows disconnecting the connected tag. \n The client is required to re-enable the apiNfcPolling, it must call the apiNfcDisconnect first.
 *  \param [out] lpdwError 		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to disconnect the opened session.
 *  \return FALSE - Fail to disconnect the open session. To get more error information, see parameter lpdwError.
 */
BOOL apiNfcDisconnect(DWORD *lpdwError);

/*! Used in function apiNfcTransceive() */
enum NFC_MifareCmd
{
    	NFC_MifareRaw			= 0x00U,     /**< Raw Command Mode.   */
    	NFC_MifareAuthentA		= 0x60U,     /**< Mifare Standard:\n
                                              This command performs an authentication with KEY A for a sector.\n
                                              Format of the buffer to send with this command :
                                              - first byte : memory (block) adress to authenticate.
                                              - next six bytes : key A.
                                              .
                                              Example: 0x \b 08 01 02 03 04 05 06 authenticates block 08 with the key 0x01[..]06.
                                              If this command fails, the user needs to reactivate the remote Mifare card
											*/
    	NFC_MifareAuthentB		= 0x61U,     /**< Mifare Standard:\n
                                              This command performs an authentication with KEY B for a sector.\n
                                              Format of the buffer to send with this command :
                                              - first byte : memory (block) adress to authenticate.
                                              - next six bytes : key B.
                                              .
                                              Example: See \ref NFC_MifareAuthentA.
                                              If this command fails, the user needs to reactivate the the remote Mifare card
											*/
    	NFC_MifareRead16		= 0x30U,     /**< Mifare Standard and Ultra Light:\n
                                              Read 16 Bytes from a Mifare Standard block or 4 Mifare Ultra Light pages.\n
                                              Format of the buffer to send with this command :
                                              - 1st (and only) byte : memory adress to read.
                                              .
                                              Example: 0x \b 08 reads the data (16 bytes) from the specified address.
                                              If this command fails, the user needs to reactivate the remote Mifare card
											*/
    	NFC_MifareRead			= 0x30U,
    	NFC_MifareWrite16		= 0xA0U,     /**< Mifare Standard:\n
                                              Write 16 bytes.\n
                                              Format of the buffer to send with this command :
                                              - first byte : start address of memory to write.
                                              - next 16 bytes : Data to write.
                                              .
                                              Example: 0x \b 08 00 01 02 03 04 05 06 07 08 09 0A 0B 0C 0D 0E 0F
                                              If this command fails, the user needs to reactivate the remote Mifare card
                                           */
    	NFC_MifareWrite4     	= 0xA2U,     /**< Mifare Ultra Light:\n
                                              Write 4 bytes.\n
                                              Format of the buffer to send with this command :
                                              - first byte : start address of memory (Mifare Ultra Light page) to write.
                                              - next 4 bytes : Data to write.
                                              .
                                              Example: 0x \b 08 00 01 02 03
                                              If this command fails, the user needs to reactivate the remote Mifare card
											*/
    	NFC_MifareInc        	= 0xC1U,     /**< Increment. */
    	NFC_MifareDec        	= 0xC0U,     /**< Decrement. */
    	NFC_MifareTransfer		= 0xB0U,     /**< Tranfer.   */
    	NFC_MifareRestore		= 0xC2U,     /**< Restore.   */
    	NFC_MifareReadSector	= 0x38U,     /**< Read Sector.   */
    	NFC_MifareWriteSector	= 0xA8U,     /**< Write Sector.   */
    	NFC_MifareInvalidCmd	= 0xFFU      /**< Invalid Command */
};
/*! Used in function apiNfcTransceive() */
enum NFC_Iso14443_4_Cmd
{
    	NFC_Iso14443_4_Raw             = 0x00U /**< ISO 14443-4 Exchange command:\n
                                                 - This command sends the data buffer directly to the remote device */
};
/*! Used in function apiNfcTransceive() */
enum NFC_Iso15693_Cmd
{
	NFC_Iso15693_Cmd					= 0x20U, /**< ISO 15693 Exchange command:\n
													- This command is used to access the card to the remote device */
	//Iso15693_Invalid					= 0xFFU      /**< Invalid Command */
	NFC_Iso15693_Inventory 				= 0x01U, /** Inventory 				 */
	NFC_Iso15693_Stay_Quite				= 0x02U, /** Stay Quite				 */
	NFC_Iso15693_Read_Single_Block 		= 0x20U, /** Read Single Block 		 */
	NFC_Iso15693_Write_Single_Block 	= 0x21U, /** Write Single Block 	 */
	NFC_Iso15693_Lock_Block				= 0x22U, /** Lock Block				 */
	NFC_Iso15693_Read_Multiple_Blocks	= 0x23U, /** Read Multiple Blocks	 */
	NFC_Iso15693_Write_Multiple_Blocks	= 0x24U, /** Write Multiple Blocks	 */
	NFC_Iso15693_ResetToReady			= 0x26U, /** ResetToReady			 */
	NFC_Iso15693_Write_AFI				= 0x27U, /** Write AFI				 */
	NFC_Iso15693_LockAFI				= 0x28U, /** LockAFI				 */
	NFC_Iso15693_WriteDSFID				= 0x29U, /** WriteDSFID				 */
	NFC_Iso15693_LockDSFID				= 0x2AU, /** LockDSFID				 */
	NFC_Iso15693_Get_System_Information	= 0x2BU, /** Get System Information	 */
	NFC_Iso15693_Get_Multiple_Block_Security_status	= 0x2CU  /** Get Multiple Block Security status */
};
/*! Used in function apiNfcTransceive() */
enum NFC_FelicaCmd
{
    	NFC_Felica_Raw             	= 0xF0U, /**< Felica Raw command:\n
                                                 - This command sends the data buffer directly to the remote device */
    	NFC_Felica_Check           	= 0x00, /**< Felica Check command:\n
                                                 - This command checks the data from the Felica remote device */
    	NFC_Felica_Update         	= 0x01, /**< Felica Update command:\n
                                                 - This command updates the data onto the Felica remote device */
    	NFC_Felica_Invalid       	= 0xFFU	/**< Invalid Command */
};
/*! Used in function apiNfcTransceive() */
enum NFC_JewelCmd
{
    	NFC_Jewel_ReadAll	= 0x00U, /**< Jewel command:\n
                                                 - This command sends the data buffer directly to the remote device */
    	NFC_Jewel_Read1		= 0x01U, /**< Read one byte. */
    	NFC_Jewel_Read4		= 0x02U, /**< Read four bytes. */
    	NFC_Jewel_Read8		= 0x03U, /**< Read eight bytes. */
    	NFC_Jewel_Write1E   = 0x53U, /**< Erase and Write one byte */
    	NFC_Jewel_Write4E   = 0x54U, /**< Erase and Write four bytes */
    	NFC_Jewel_Write8E   = 0x55U, /**< Erase and Write eight bytes */
    	NFC_Jewel_Write1NE	= 0x1AU, /**< Write one byte Without Erase */
    	NFC_Jewel_Write4NE	= 0x1BU, /**< Write four bytes Without Erase */
    	NFC_Jewel_Write8NE	= 0x1CU, /**< Write eight bytes Without Erase */
    	NFC_Jewel_RID		= 0x78U, /**< Read the identification information */
    	NFC_Jewel_ReadSeg	= 0x10U, /**< Read the data segment */
    	NFC_Jewel_Read		= 0x21U, /**< Read the data from the specified block  */
    	NFC_Jewel_Write		= 0x22U, /**< Write the data to specified block  */
    	NFC_Jewel_Invalid	= 0xFFU  /**< Invalid jewel command */
};
/*!
 *  \brief This function is called to transmit and receive data to and from the tag.
 *  \param [in] dwFormatType		This parameter defines the type of data format (defined in enum NFC_DATA_FORMAT_TYPE).
 *  \param [out] lpdwOutSize		Pointer to the buffer which contains data to transmit.
 *  \param [out] lpOutData			Pointer to the buffer which contains data to transmit.
 *  \param [in] dwInSize			Pointer to the number of bytes which received from remote object.
 *  \param [in] lpInData			Pointer to the buffer which receives data from remote object.
 *  \param [in] dwCommand		This parameter defines the command of type cards.
 *  \param [in] dwBlock		This parameter defines block number. (reserved, set as 0 for now)
 *  \param [out] lpdwError 			A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return A negative value indicates error. Otherwise, the value is the number of bytes copied into the location pointed out by InData. To get more error information, see parameter lpdwError.
 */
DWORD apiNfcTransceive(DWORD dwFormatType, DWORD *lpdwOutSize, void *lpOutData, DWORD dwInSize, const void *lpInData, DWORD dwCommand, DWORD dwBlock, DWORD *lpdwError);

#if 0
/*!
 *  \brief This function performs firmware upgrade.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to perform firmware upgrade.
 *  \return FALSE - Fail to perform firmware upgrade. To get more error information, see parameter lpdwError.
 */
BOOL apiNfcFWUpgrade(DWORD *lpdwError);
#endif

/*! @} */


/*! \addtogroup GP7 Smart Card / SAM Module
  *  Use Microsoft standard API to control Smart Card / SAM Module related functions.
  *  @{
  */

/*! @} */


/*! \addtogroup GP8 Camera
  *  Use Microsoft standard DirectX interface to control Camera related functions (including Auto-Focus).
  *  @{
  */

/*! @} */


/*! \addtogroup GP9 Vibrator
  *  The part will be implemented by windows mobile API: NledSetDevice()
  *  @{
  */

/*! @} */


/*! \addtogroup GP10 Custom ROM File Transfer Sample
  *  The following definition and functions are for 'Custom ROM File Transfer Sample'
  *  @{
  */
/*!
 *  \brief This function will format the Custom ROM partition.
 *  \param [in] lpszPartitionName		A null-terminated string specifying the name of partition to format.
 *  \param [out] lpdwError				A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to format the Custom ROM partition.
 *  \return FALSE - Fail to format the Custom ROM partition. To get more error information, see parameter lpdwError.
 */
BOOL apiFormatCustomROM(LPCTSTR lpszPartitionName, DWORD *lpdwError);

/*!
 *  \brief This function will copy all the files in "CopyToCustomROM" folder of micro SD-card to Custom ROM area. \n But excluding "CustomROMTool.exe".
 *  \param [in] lpszPartitionName 		A null-terminated string specifying the partition name containing "CopyToCustomROM" folder.
 *  \param [out] lpdwError 				A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - All the files in "CopyToCustomROM" folder of micro SD-card are successfully copy to the Custom ROM area.
 *  \return FALSE - An error occurred. If there is not enough storage to complete this operation, it will return FALSE. 
 *  \par Sample Code:
 *  \code
 DWORD getErr=0;
 BOOL suc = apiBatchCopyToCustomROM(_T("\\CustomROM"), &getErr); 
 *  \endcode
 */
BOOL apiBatchCopyToCustomROM(LPCTSTR lpszPartitionName, DWORD *lpdwError);

/*! Used in function apiFactoryReset() */
enum DEVICE_RESET_TYPE
{
	DEVICE_RESET_TYPE_FACTORY_RESET,							/**< Factory Reset */
	DEVICE_RESET_TYPE_CLEAN_BOOT								/**< Clean Boot   */
};

/*!
 *  \brief This function will perform Factory Reset or Clean Boot. \n Clean Boot will all remove applications, restore registry and databases to default. \n Factory Reset will do a clean boot AND also format the Custom ROM area and the Flash Disk.
 *  \param [in] dwResetType		A DWORD specifying which type of factory reset to perform. \n Could be any member defined in enum DEVICE_RESET_TYPE.
 *  \param [out] lpdwError 		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to perform factory reset or clean boot.
 *  \return FALSE - Fail to perform factory reset or clean boot. To get more error information, see parameter lpdwError.
 */
BOOL apiFactoryReset(DWORD dwResetType, DWORD *lpdwError);

/*! @} */


/*! \addtogroup GP11 Flash LED
  *  The part will be implemented by windows mobile API: NledSetDevice()
  *  @{
  */

/*! @} */


/*! \addtogroup GP12 Status LED
  *  The part will be implemented by windows mobile API: NledSetDevice()
  *  @{
  */

/*! @} */


/*! \addtogroup GP13 Keyboard Backlight
  *  The part will be implemented by windows mobile API: NledSetDevice()
  *  @{
  */
#if 0
enum KEYBOARD_BACKLIGHT_MODE_TYPE
{
	KEYBOARD_BACKLIGHT_MODE_ON,							/**< Keyboard backlight is always on */
	KEYBOARD_BACKLIGHT_MODE_OFF,						/**< Keyboard backlight is always off */
	KEYBOARD_BACKLIGHT_MODE_AUTO,						/**< Keyboard backlight is automatically controlled */
};

/*!
 *  \brief This function is used to set keyboard backlight mode.
 *  \param [in] dwKbMode		A DWORD specifying the keyboard mode to set (defined in enum KEYBOARD_BACKLIGHT_MODE_TYPE).
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success.
 *  \return FALSE - Fail. To get more error information, see parameter lpdwError.
 */
BOOL apiSetKeyboardBackLightMode (DWORD dwKbMode, DWORD *lpdwError);

/*!
 *  \brief This function is used to set keyboard backlight mode.
 *  \param [out] lpdwKbMode	A pointer to a DWORD to retrieve current keyboard mode (defined in enum KEYBOARD_BACKLIGHT_MODE_TYPE).
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success.
 *  \return FALSE - Fail. To get more error information, see parameter lpdwError.
 */
BOOL apiGetKeyboardBackLightMode (DWORD *lpdwKbMode, DWORD *lpdwError);

/*!
 *  \brief This function is used to set the keyboard backlight pulse width (backlight's turn on time) in millisecond, it's only workable when Backlight is in Auto mode, default value is 1000.
 *  \param [in] dwTime			A DWORD specifying time value in millisecond.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success.
 *  \return FALSE - Fail. To get more error information, see parameter lpdwError.
 */
BOOL apiSetMcuBKLPluseWith(DWORD dwTime, DWORD *lpdwError);

/*!
 *  \brief This function is used to get the keyboard backlight pulse width (backlight's turn on time) in millisecond.
 *  \param [out] lpdwTime		A pointer to a DWORD to retrieve time value in millisecond.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success.
 *  \return FALSE - Fail. To get more error information, see parameter lpdwError.
 */
BOOL apiGetMcuBKLPluseWith(DWORD *lpdwTime, DWORD *lpdwError);
#endif
/*! @} */


/*! \addtogroup GP14 Power
  *  The following definition and functions are for 'Power'
  *  @{
  */

/*! Used in function apiSetBacklightBrightness() and apiGetBacklightBrightness()*/
enum POWER_MODE
{
	POWER_MODE_BATTERY,							/**< on battery power */
	POWER_MODE_EXTERNAL,							/**< on external power */
};
/*! Used in function apiSetBacklightBrightness() and apiGetBacklightBrightness()*/
enum BACKLIGHT_BRIGHTNESS
{
	BACKLIGHT_BRIGTHNESS_OFF,						/**< Backlight is Off */
	BACKLIGHT_BRIGTHNESS_1,							/**< Backlight brightness level 1 (darkest) */
	BACKLIGHT_BRIGTHNESS_2,							/**< Backlight brightness level 2 */
	BACKLIGHT_BRIGTHNESS_3,							/**< Backlight brightness level 3 */
	BACKLIGHT_BRIGTHNESS_4,							/**< Backlight brightness level 4 (brightest) */
};

/*!
 *  \brief This function will set the brightness level value of screen backlight for either on battery power or on external power.
 *  \param [in] dwStatus		A DWORD specifying whether the brightness level to set is for the status of either battery only or external power. (defined in enum POWER_MODE)
 *  \param [in] dwValue			A DWORD specifying the brightness level to set. (defined in enum BACKLIGHT_BRIGHTNESS)
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to set the brightness level value.
 *  \return FALSE - Fail to set the brightness level value. To get more error information, see parameter lpdwError.
 */
BOOL apiSetBacklightBrightness(DWORD dwStatus, DWORD dwValue, DWORD *lpdwError);

/*!
 *  \brief This function will get the brightness level value of screen backlight for both on battery power or on external power.
 *  \param [in] dwStatus		A DWORD specifying whether the brightness level to set is for the status of either battery only or external power. (defined in enum POWER_MODE)
 *  \param [out] lpdwValue		A pointer to a DWORD to retrieve brightness level. (defined in enum BACKLIGHT_BRIGHTNESS)
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get the brightness level value.
 *  \return FALSE - Fail to get the brightness level value. To get more error information, see parameter lpdwError.
 */
BOOL apiGetBacklightBrightness(DWORD dwStatus, DWORD *lpdwValue, DWORD *lpdwError);

/*! Used in function apiGetBackupBatteryStatus()*/
enum BACKUP_BATTERY_STATUS
{	
	BACKUP_BATTERY_STATUS_BAD,						/**< Backup battery is bad */	
	BACKUP_BATTERY_STATUS_GOOD,						/**< Backup battery is good */
};
/*!
 *  \brief This function will get the status of bakeup battery. 
 *  \param [out] lpdwStatus		A pointer to a DWORD to retrieve brightness level. (defined in enum BACKUP_BATTERY_STATUS)
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to get the backup battery status.
 *  \return FALSE - Fail to get the backup battery status. To get more error information, see parameter lpdwError.
 */
BOOL apiGetBackupBatteryStatus(DWORD *lpdwStatus, DWORD *lpdwError);

/*!
 *  \brief This function can be used to suspend the device.
 *  \param [out] lpdwError		A pointer to a DWORD to retrieve error information (defined in enum DI_ERRORNO).
 *  \return TRUE - Success to suspend the device.
 *  \return FALSE - Fail to suspend the device. To get more error information, see parameter lpdwError.
 */
BOOL apiSuspendDevice(DWORD *lpdwError);

/*! @} */

#ifndef _PC_EMULATOR
}
#endif

#endif	//	#ifnded	_IACUTIL_H_
